# Changelog

All notable changes to this project will be documented in this file.

## [0.2.3] - 2025-02-09

### 🚀 Features

- Add option to specify tag prefix in version command (#111)

### 📚 Documentation

- Create proper README.md (#106)
- Add python 3.13 classifier (#107)
- Lint and format all Markdown files (#108)

### ⚙️ Miscellaneous Tasks

- Rename check jobs (#110)

<!-- generated by git-cliff -->
